@@ -17,7 +17,7 @@ class Folder:
         'md5': None,     # string - File MD5 checksum. This is sometimes delayed, so if you get a blank response, wait and try again.
         'mime_type': None,     # string - MIME Type.  This is determined by the filename extension and is not stored separately internally.
         'region': None,     # string - Region location
-        'permissions': None,     # string - A short string representing the current user's permissions.  Can be `r`,`w`,`p`, or any combination
+        'permissions': None,     # string - A short string representing the current user's permissions.  Can be `r`,`w`,`d`, `l` or any combination
         'subfolders_locked?': None,     # boolean - Are subfolders locked and unable to be modified?
         'download_uri': None,     # string - Link to download file. Provided only in response to a download request.
         'priority_color': None,     # string - Bookmark/priority color of file/folder
